[Xorg-commit] xc/programs/Xserver/hw/darwin/quartz/xpr xprScreen.c,1.1.4.1,1.1.4.2

Kaleb Keithley xorg-commit at pdx.freedesktop.org
Thu Dec 18 21:29:45 EET 2003


Committed by: kaleb

Update of /cvs/xorg/xc/programs/Xserver/hw/darwin/quartz/xpr
In directory pdx:/home/kaleb/xorg/xc.XORG-CURRENT/programs/Xserver/hw/darwin/quartz/xpr

Modified Files:
      Tag: XORG-CURRENT
	xprScreen.c 
Log Message:
First pass at "Standard" Xinerama.
The sources for this came from Heather Lanigan's xinerama tree on 
Sourceforge.Net. 
No attempt has been made to handle previous, non-standard versions of 
the protocol. Nor has any attempt been made to preserve the ABI of 
previous versions -- that part will be added at a later time, and 
then probably only on systems that have nice object/linker semantics, 
e.g. ELF systems with weak symbols.



Index: xprScreen.c
===================================================================
RCS file: /cvs/xorg/xc/programs/Xserver/hw/darwin/quartz/xpr/xprScreen.c,v
retrieving revision 1.1.4.1
retrieving revision 1.1.4.2
diff -u -d -r1.1.4.1 -r1.1.4.2
--- xprScreen.c	6 Dec 2003 13:24:23 -0000	1.1.4.1
+++ xprScreen.c	18 Dec 2003 19:29:13 -0000	1.1.4.2
@@ -1,3 +1,4 @@
+/* $XdotOrg$ */
 /*
  * Xplugin rootless implementation screen functions
  */
@@ -27,13 +28,12 @@
  * holders shall not be used in advertising or otherwise to promote the sale,
  * use or other dealings in this Software without prior written authorization.
  */
-/* $XdotOrg$ */
 /* $XFree86: xc/programs/Xserver/hw/darwin/quartz/xpr/xprScreen.c,v 1.9 2003/11/27 01:59:53 torrey Exp $ */
 
 #include "quartzCommon.h"
 #include "quartz.h"
 #include "xpr.h"
-#include "pseudoramiX.h"
+#include "pseudorama.h"
 #include "darwin.h"
 #include "rootless.h"
 #include "safeAlpha.h"
@@ -139,11 +139,11 @@
 
 
 /*
- * addPseudoramiXScreens
- *  Add a physical screen with PseudoramiX.
+ * addPseudoramaScreens
+ *  Add a physical screen with Pseudorama.
  */
 static void
-addPseudoramiXScreens(int *x, int *y, int *width, int *height)
+addPseudoramaScreens(int *x, int *y, int *width, int *height)
 {
     CGDisplayCount i, displayCount;
     CGDirectDisplayID *displayList = NULL;
@@ -168,24 +168,24 @@
     *width = unionRect.size.width;
     *height = unionRect.size.height;
 
     /* Tell PseudoramiX about the real screens. */
     for (i = 0; i < displayCount; i++)
     {
         CGDirectDisplayID dpy = displayList[i];
 
         frame = displayScreenBounds(dpy);
 
-        ErrorF("PseudoramiX screen %d added: %dx%d @ (%d,%d).\n", i,
+        ErrorF("Pseudorama screen %d added: %dx%d @ (%d,%d).\n", i,
                (int)frame.size.width, (int)frame.size.height,
                (int)frame.origin.x, (int)frame.origin.y);
 
         frame.origin.x -= unionRect.origin.x;
         frame.origin.y -= unionRect.origin.y;
 
-        ErrorF("PseudoramiX screen %d placed at X11 coordinate (%d,%d).\n",
+        ErrorF("Pseudorama screen %d placed at X11 coordinate (%d,%d).\n",
                i, (int)frame.origin.x, (int)frame.origin.y);
 
-        PseudoramiXAddScreen(frame.origin.x, frame.origin.y,
+        PseudoramaAddScreen(frame.origin.x, frame.origin.y,
                              frame.size.width, frame.size.height);
     }
 
@@ -206,10 +206,10 @@
 
     CGGetActiveDisplayList(0, NULL, &displayCount);
 
     /* With PseudoramiX, the X server only sees one screen; only PseudoramiX
        itself knows about all of the screens. */
 
-    if (noPseudoramiXExtension)
+    if (noPseudoramaExtension)
         darwinScreensFound = displayCount;
     else
         darwinScreensFound =  1;
@@ -270,7 +270,7 @@
         dfb->colorBitsPerPixel = 8;
     }
 
-    if (noPseudoramiXExtension)
+    if (noPseudoramaExtension)
     {
         CGDirectDisplayID dpy;
         CGRect frame;
@@ -286,7 +286,7 @@
     }
     else
     {
-        addPseudoramiXScreens(&dfb->x, &dfb->y, &dfb->width, &dfb->height);
+        addPseudoramaScreens(&dfb->x, &dfb->y, &dfb->width, &dfb->height);
     }
 
     /* Passing zero width (pitch) makes miCreateScreenResources set the
@@ -168,24 +168,24 @@
     *height = unionRect.size.height;
 
-    /* Tell PseudoramiX about the real screens. */
+    /* Tell Pseudorama about the real screens. */
     for (i = 0; i < displayCount; i++)
     {
@@ -206,10 +206,10 @@
     CGGetActiveDisplayList(0, NULL, &displayCount);
 
-    /* With PseudoramiX, the X server only sees one screen; only PseudoramiX
+    /* With Pseudorama, the X server only sees one screen; only Pseudorama
        itself knows about all of the screens. */
 





More information about the xorg-commit mailing list